var NAVTREEINDEX11 =
{
"group__API__Task__Lists.html#ad80731caf9d45900687caa7d5cc17cae":[57,8,0,1],
"group__API__Task__Lists.html#af66edbac990d8e894796ca5d5dd45138":[57,8,0,0],
"group__API__Task__Lists.html#ga02a847856d87dc7027c6f57e22a9e481":[57,8,12],
"group__API__Task__Lists.html#ga1a9fbeedd7b9b0f77a18a8754a1bdeab":[57,8,13],
"group__API__Task__Lists.html#ga367d90424e132d762e9a11eac2a822af":[57,8,10],
"group__API__Task__Lists.html#ga37f7421eb2dcf9d808220db8454f0fac":[57,8,11],
"group__API__Task__Lists.html#ga5618612b0ce2f914ab9032474ddf072f":[57,8,1],
"group__API__Task__Lists.html#ga56ae6bd10619777a164ace85197034c4":[57,8,5],
"group__API__Task__Lists.html#ga78d4f98e2d6f2f73d453c86ca8ca9e95":[57,8,4],
"group__API__Task__Lists.html#gabf5bb8daf00f9902ea501009720af19d":[57,8,2],
"group__API__Task__Lists.html#gad0e3e0684ea77c786b7c5b83894b5e5d":[57,8,8],
"group__API__Task__Lists.html#gad88622cd18759da0a9b30ca75c11e22b":[57,8,9],
"group__API__Task__Lists.html#gadbb9076de7513b41c19813e16a3c0773":[57,8,6],
"group__API__Task__Lists.html#gadfa0c59a4171d62adfb68daafb73ed89":[57,8,14],
"group__API__Task__Lists.html#gae29a8aae4e82286c80656a7afdc7a106":[57,8,3],
"group__API__Task__Lists.html#gaedf8ff832aea57abbb8ab94304a85c13":[57,8,7],
"group__API__Task__Lists.html#structstarpu__task__list":[57,8,0],
"group__API__Theoretical__Lower__Bound__on__Execution__Time.html":[57,27],
"group__API__Theoretical__Lower__Bound__on__Execution__Time.html#ga066ce2e396d5b676af7a5209b0079610":[57,27,4],
"group__API__Theoretical__Lower__Bound__on__Execution__Time.html#ga284f3571becb60b2354cc1ce121e4778":[57,27,0],
"group__API__Theoretical__Lower__Bound__on__Execution__Time.html#ga5f1859599a28105aea4c0f33fd871218":[57,27,1],
"group__API__Theoretical__Lower__Bound__on__Execution__Time.html#ga7fc9141929ef926d346431307afb0ff1":[57,27,2],
"group__API__Theoretical__Lower__Bound__on__Execution__Time.html#ga834aa7094c173d42985d4d70f1694f57":[57,27,6],
"group__API__Theoretical__Lower__Bound__on__Execution__Time.html#ga99f073d0ad7604366ef3a8f805b5f060":[57,27,3],
"group__API__Theoretical__Lower__Bound__on__Execution__Time.html#gad0cf05d0bb9b21964fb911cfebf252df":[57,27,5],
"group__API__Threads.html":[57,43],
"group__API__Threads.html#ga0573dd7985127d363fd5dbcb8d67796b":[57,43,61],
"group__API__Threads.html#ga07cf3c3cea2261713d45480dc43cfe58":[57,43,42],
"group__API__Threads.html#ga0a47c0f221c5d06bd2060be964fbaeb2":[57,43,32],
"group__API__Threads.html#ga0bee487f84485eb56515df6e76049708":[57,43,46],
"group__API__Threads.html#ga0f4c9033a1cbf7b7ef88c5124a65149f":[57,43,9],
"group__API__Threads.html#ga0f576d7a841d598e1f8c78390a539ab6":[57,43,19],
"group__API__Threads.html#ga12b51a2c0058eae72c2e970bcc21386e":[57,43,50],
"group__API__Threads.html#ga14c8ef52495a1b70d40d10b1b241584b":[57,43,59],
"group__API__Threads.html#ga1a9e6ff32713348b5aee92bf00717639":[57,43,44],
"group__API__Threads.html#ga1f1dd00ce9f4e8ee935d100a056673f2":[57,43,53],
"group__API__Threads.html#ga203116e24fb6fcf0489c9a50cca73510":[57,43,18],
"group__API__Threads.html#ga212042108827f44d9405d0a514e03f95":[57,43,54],
"group__API__Threads.html#ga2331ffac0d863e2d34463003fa961550":[57,43,14],
"group__API__Threads.html#ga2463ea91106a5f4510bd407c049d6159":[57,43,47],
"group__API__Threads.html#ga2612e4e867add0050df8e2678838077a":[57,43,56],
"group__API__Threads.html#ga28942688ecde4a23020c9ad0e2051151":[57,43,43],
"group__API__Threads.html#ga2bd1ebeca9a2d4eefc3d0a399ce3ae3c":[57,43,24],
"group__API__Threads.html#ga348ba00ab90144b68f094631fb3657de":[57,43,16],
"group__API__Threads.html#ga3b181bf45271e3c6b144277959b6d487":[57,43,49],
"group__API__Threads.html#ga3e6f70cbaed94500cd4b8229db361a7a":[57,43,63],
"group__API__Threads.html#ga402f8687fe2f6f7277c692fa6c1d0d29":[57,43,36],
"group__API__Threads.html#ga42b7eaa98fe66b90eb67f3fdb51fd14d":[57,43,20],
"group__API__Threads.html#ga43ef5044dfe6169c422d3ded42aa69e4":[57,43,1],
"group__API__Threads.html#ga4b4dc49f4d02c93e9b5364e9fb8f148f":[57,43,33],
"group__API__Threads.html#ga4f00fbbe6f909998ecec7c3cc3715e21":[57,43,55],
"group__API__Threads.html#ga5bc60d93e1403658c30c998d1b6edd11":[57,43,52],
"group__API__Threads.html#ga5e53025adc42966a97d616304bd654bd":[57,43,6],
"group__API__Threads.html#ga5ec606cedc543ee35f3c7dc8a8e2505b":[57,43,64],
"group__API__Threads.html#ga629152a86070cd58811fa17506f7995e":[57,43,12],
"group__API__Threads.html#ga654b486b4161002221a75cc619eabe48":[57,43,30],
"group__API__Threads.html#ga670ae411d7536934d784c88c6d11177c":[57,43,28],
"group__API__Threads.html#ga707b1afc766917d4ddbbe19e5569359b":[57,43,23],
"group__API__Threads.html#ga7cf8cbee2a33b4714cf37724f657bd4a":[57,43,15],
"group__API__Threads.html#ga81126f750a75beef8a9679dd261e1bd2":[57,43,21],
"group__API__Threads.html#ga85907c2f14430e01fea27280ed3ac2ae":[57,43,41],
"group__API__Threads.html#ga8cda60ccc235761b6fea9ec2204da362":[57,43,3],
"group__API__Threads.html#ga8d9b7c62dc30af6fdf84acf0367e2b43":[57,43,58],
"group__API__Threads.html#ga8fd0aa9fa9c38abbdcb91047eccf34e5":[57,43,38],
"group__API__Threads.html#ga9d53e88546b413acd8b1312acd885966":[57,43,29],
"group__API__Threads.html#ga9ef49f133fa6f1374769aab8a4ff9474":[57,43,65],
"group__API__Threads.html#gaa0871b23fee2d5cfa1e4930108b53708":[57,43,25],
"group__API__Threads.html#gaa8d07e258b61aa10fc8ce2111f4a37a9":[57,43,67],
"group__API__Threads.html#gaad19009cc7f31a2b5bd8bc3e3d000e45":[57,43,39],
"group__API__Threads.html#gab1d60ac7acd857f056de5d9cdd3b8b93":[57,43,2],
"group__API__Threads.html#gab1f13e8c7f4e9c7a93e35ffa5f3c8925":[57,43,7],
"group__API__Threads.html#gab24c9ad484185c1b0fc2518a27824041":[57,43,11],
"group__API__Threads.html#gab3f630ba782864f80fb7d8fceb7db399":[57,43,60],
"group__API__Threads.html#gab522d9c9ae9747db8123344f49421725":[57,43,62],
"group__API__Threads.html#gab99612af964c7e92d99e3fcc9513c909":[57,43,4],
"group__API__Threads.html#gaba0e781d7d8a22c313200edaa9ec59f9":[57,43,17],
"group__API__Threads.html#gac1f65845c0c1c76e65c63fc5174ff5cb":[57,43,8],
"group__API__Threads.html#gac59327fea4e8f540a378c41b1157d367":[57,43,57],
"group__API__Threads.html#gac5bf366536c4f722dec41da48618b937":[57,43,66],
"group__API__Threads.html#gac83bf1cce7a509b76cae9e191fb39bb4":[57,43,27],
"group__API__Threads.html#gac93d8e7fcb44d354421a77b1c0bc9569":[57,43,26],
"group__API__Threads.html#gacabc76c4b40c66603b5d417d7039439a":[57,43,5],
"group__API__Threads.html#gad37f49e0fb051b7a3a66208a4bc67397":[57,43,22],
"group__API__Threads.html#gadcaa2002f0cd921e66afca18a63ccb88":[57,43,45],
"group__API__Threads.html#gadda164742adc172cb99860c88363ecd8":[57,43,34],
"group__API__Threads.html#gadecb508e5f50f8cf5c90626bdaca17fa":[57,43,35],
"group__API__Threads.html#gae024574a5ff66361d2b00f10924dbf3a":[57,43,10],
"group__API__Threads.html#gaea6e537f9a02061690e845082158b3b4":[57,43,0],
"group__API__Threads.html#gaebaf9c865b4a20d01a6017a11053c223":[57,43,37],
"group__API__Threads.html#gaede3f824ce3ecf6079987a68da9eb621":[57,43,13],
"group__API__Threads.html#gaf16bdf5df80097a4fbd08b23af68f829":[57,43,51],
"group__API__Threads.html#gafafe5e882f4be0f494a978dc0853d527":[57,43,48],
"group__API__Threads.html#gaff16a92b547683cc3891dfb1faca1e3a":[57,43,40],
"group__API__Threads.html#gaffe50be0f786d9a529a9946171469879":[57,43,31],
"group__API__Toolbox.html":[57,32],
"group__API__Toolbox.html#ga057b12b615ce9e8a1fe7b5e10d9a5c2e":[57,32,10],
"group__API__Toolbox.html#ga05ac0dda104331f57d85823a4f9318ce":[57,32,12],
"group__API__Toolbox.html#ga07b2628bd6680fe49d92c7f816d7ce53":[57,32,22],
"group__API__Toolbox.html#ga10dac0e97a9c6bcc9ae042e067c508ae":[57,32,14],
"group__API__Toolbox.html#ga1b41d799a04a1d6483e982ffb2f74432":[57,32,20],
"group__API__Toolbox.html#ga214c60ee1b6cbc27ab08ba6f339ef8e5":[57,32,8],
"group__API__Toolbox.html#ga230129f89ca986b143c6b059a9229fb7":[57,32,4],
"group__API__Toolbox.html#ga23742c6fca8b5386e1f3e3f7bbf3a692":[57,32,1],
"group__API__Toolbox.html#ga3a4d1fb56668323d4f44c18f6a6dfb3f":[57,32,17],
"group__API__Toolbox.html#ga4268950ebf63c0f1dabcfd0cd8808067":[57,32,18],
"group__API__Toolbox.html#ga4456c2db2cc8df7c98d62ecc21b2bd1d":[57,32,2],
"group__API__Toolbox.html#ga4fc771a29d7dc0e826da42777edbcf15":[57,32,0],
"group__API__Toolbox.html#ga71e28fc2a0a5267bc7edc0909d9d5117":[57,32,9],
"group__API__Toolbox.html#ga725920b5267625bff19f49219ff2d4d8":[57,32,13],
"group__API__Toolbox.html#ga7df091d95d10b854c16cd1cd65cf7508":[57,32,6],
"group__API__Toolbox.html#ga9804db3e8ffb845492154f63e7d6ae95":[57,32,7],
"group__API__Toolbox.html#ga9e7c20a6cdce868976a0046206b104e6":[57,32,3],
"group__API__Toolbox.html#gaa3503ea5efd00806a0f9234f033e6ea1":[57,32,19],
"group__API__Toolbox.html#gaa5363993d4f519517316ccf9dc47a7bb":[57,32,21],
"group__API__Toolbox.html#gabb6941113e19ee4045a014943cd62aae":[57,32,16],
"group__API__Toolbox.html#gad3ac8d7f5a35aa9c65dcca9915f9a750":[57,32,15],
"group__API__Toolbox.html#gae07407908792f54312150228d70dbece":[57,32,5],
"group__API__Toolbox.html#gae8c513ecd1a5bd87a7bdd71260c49ffc":[57,32,11],
"group__API__Transactions.html":[57,3],
"group__API__Transactions.html#ga4a31681d2f0cb458570d4acb50ee1b0f":[57,3,2],
"group__API__Transactions.html#ga85c17fa938cac5969d6e2872c660a1a6":[57,3,0],
"group__API__Transactions.html#gac33728c32906466d0aac40646aa2614d":[57,3,1],
"group__API__Tree.html":[57,44],
"group__API__Tree.html#structstarpu__tree":[57,44,0],
"group__API__Versioning.html":[57,1],
"group__API__Versioning.html#ga43895a109dc6f27de709208f460b321d":[57,1,2],
"group__API__Versioning.html#ga61698352a3ca7e28b4bcdd8bcad8d8cc":[57,1,0],
"group__API__Versioning.html#ga847f129c7b859f46c8bd69c9c8cbcde5":[57,1,1],
"group__API__Versioning.html#gaa9151820d2ef6a8231b510b4b3c19ca4":[57,1,3],
"group__API__Workers.html":[57,14],
"group__API__Workers.html#a0d213fc6e036df7424e05c30bfca22c4":[57,14,1,0],
"group__API__Workers.html#a10961e3af7749f812b744dbd9f85da96":[57,14,1,1],
"group__API__Workers.html#a1782f997e873faa64de39cf4bd570661":[57,14,1,6],
"group__API__Workers.html#a26ad74518560f75a4cd9e1ee0cb2eb7c":[57,14,1,8],
"group__API__Workers.html#a3460c754c642b2244d4c2ceb98101ece":[57,14,0,0],
"group__API__Workers.html#a6595f14b6715e60d2444f4cd09b9d73f":[57,14,1,3],
"group__API__Workers.html#ab92e3de048f56a4c2f59fa804594c339":[57,14,1,4],
"group__API__Workers.html#acbe5dc434c779fec539a427b8e8ab1aa":[57,14,1,2],
"group__API__Workers.html#adf52d25f085ea1f6fe2b982b3439b73f":[57,14,1,7],
"group__API__Workers.html#ae039a760cdd80c0d91bcc4c4da9ebb74":[57,14,1,5],
"group__API__Workers.html#ae260b3aeb9f58a98d7adb70eea8b851c":[57,14,1,9],
"group__API__Workers.html#ga03d66f459ebae08349fa50042fe37808":[57,14,46],
"group__API__Workers.html#ga0c9b9b7f5195cb8cbc5ee1223ec0f264":[57,14,34],
"group__API__Workers.html#ga0dd6ff2d77c6a520a6cc4c051eb40bfa":[57,14,18],
"group__API__Workers.html#ga1056809a8cd464002ed4cad02cec33e4":[57,14,67],
"group__API__Workers.html#ga130075042017ad3794ba2321743088c6":[57,14,50],
"group__API__Workers.html#ga1552f16bc4b25d839efc732180efa130":[57,14,43],
"group__API__Workers.html#ga173d616aefe98c33a47a847fd2fca37d":[57,14,9],
"group__API__Workers.html#ga177bffe36c7df3f91aaebe2dd03b8cda":[57,14,2],
"group__API__Workers.html#ga178dd465219373d9da366fff593d56fa":[57,14,17],
"group__API__Workers.html#ga1c6e6bcceeb1c5d4edafa9d933d15cc2":[57,14,23],
"group__API__Workers.html#ga1c9cefba8ede1b63cef4a617a73f7d2c":[57,14,54],
"group__API__Workers.html#ga1d20d159f519df135fb1ac954a29bccf":[57,14,58],
"group__API__Workers.html#ga21213e018976d3876c85d3ca9ac1dff9":[57,14,31],
"group__API__Workers.html#ga2b75b2600f85996e943ece2631971c62":[57,14,13],
"group__API__Workers.html#ga2c930d982bacf4bf4dce015ab2d61123":[57,14,66],
"group__API__Workers.html#ga35c8908fd60c0407901872b25a8a88da":[57,14,68],
"group__API__Workers.html#ga389142e108345483dc8c0bf07465263c":[57,14,49],
"group__API__Workers.html#ga38c0b1858730fec2211991147a964910":[57,14,69],
"group__API__Workers.html#ga39b7e2b82022313535c7b0015c2a0176":[57,14,45],
"group__API__Workers.html#ga3a6a9eddecb3e97b3c37e151003ea7c2":[57,14,32],
"group__API__Workers.html#ga3c4c7e122c29d884fe1674434b69cf52":[57,14,22],
"group__API__Workers.html#ga3f985e55d355aa7b1c83471230b37a39":[57,14,39],
"group__API__Workers.html#ga3fa9784ddcf3fc9f496e33fe4cad54ce":[57,14,38],
"group__API__Workers.html#ga40eea17cbbabcb0eed906d0b50604ed2":[57,14,63],
"group__API__Workers.html#ga45611e9799d1c32e826c5f2f6a642c65":[57,14,51],
"group__API__Workers.html#ga479f8ed78324dca80ad746d0fee5d832":[57,14,7],
"group__API__Workers.html#ga4998e4e1dfa0d121059c60f790496a03":[57,14,24],
"group__API__Workers.html#ga53bac558c693f8cfdeef94bc6b64ab0b":[57,14,53],
"group__API__Workers.html#ga5728fe0e4be069e45c4cd0ac0319d8a0":[57,14,47],
"group__API__Workers.html#ga57687262112024abc0082b01b72ff0e8":[57,14,59],
"group__API__Workers.html#ga5877310a0fae5f20967027fcb214c7aa":[57,14,37],
"group__API__Workers.html#ga60b4a796a3dba40e5159158750805bf2":[57,14,25],
"group__API__Workers.html#ga6312aa4b12ce7e06fe391bcafda6796a":[57,14,14],
"group__API__Workers.html#ga65ceee59fa79646aa5d2447eb2b17037":[57,14,11],
"group__API__Workers.html#ga6f3fbb6e918d0135ccb68473a8ee5ca1":[57,14,8],
"group__API__Workers.html#ga76d913164202fc836d6f76811371db0c":[57,14,71],
"group__API__Workers.html#ga7703495d0659819cef60634c1b704af2":[57,14,33],
"group__API__Workers.html#ga7de6654141ce89ea83c3aba60486396e":[57,14,52],
"group__API__Workers.html#ga80b06886ee8a4c0e99b09ab638113af3":[57,14,10],
"group__API__Workers.html#ga81227c4d4758d9f1b4a12cc3ecfc8a96":[57,14,55],
"group__API__Workers.html#ga832ce3b4d20a3f94da0d681965e8eea1":[57,14,41],
"group__API__Workers.html#ga8c4e370ff327c38a3ec79c9249ab233a":[57,14,15],
"group__API__Workers.html#ga8dc923de752528ca92c129c00af3703e":[57,14,70],
"group__API__Workers.html#ga9381b07c96aa7d1d0e6edeb338b2fd94":[57,14,29],
"group__API__Workers.html#ga95b8a935e52957f51659be8abad46668":[57,14,35],
"group__API__Workers.html#ga9b2541fc1a20c4c486c499af01a3283c":[57,14,60],
"group__API__Workers.html#gaa6e5fd90ba1b431ed025006d190fb421":[57,14,5],
"group__API__Workers.html#gaa7a73dac05f65d5760abf29016e251f0":[57,14,3],
"group__API__Workers.html#gaad05388dbafdd5397ebe080913a7b0c8":[57,14,19],
"group__API__Workers.html#gaafe3ee2f7b074f95e8bc79eeabda0f0f":[57,14,4],
"group__API__Workers.html#gab0ffe5622c5980444226f1ed8d6fee71":[57,14,27],
"group__API__Workers.html#gab48ee9207771b65673f5bb18885c8a7c":[57,14,12],
"group__API__Workers.html#gab568e2368c11f9fb362f04264ad4cd04":[57,14,65],
"group__API__Workers.html#gabb530cc7597d5a135b900760f45c9cde":[57,14,61],
"group__API__Workers.html#gac043c52077692456604a2f2f161b86ba":[57,14,57],
"group__API__Workers.html#gac5ac7db6daab005d9c36c2481d984b66":[57,14,40],
"group__API__Workers.html#gac6d06f4e22b63bf50bc8e836cf16f81f":[57,14,21],
"group__API__Workers.html#gacb9d262c066c047ae55f691adc876db3":[57,14,16],
"group__API__Workers.html#gacdc94f67f203028dbfc25a2e8b588bb5":[57,14,62],
"group__API__Workers.html#gace5e9c1624f4d6449b22857b38326e9e":[57,14,73],
"group__API__Workers.html#gad3f993a7ab14f16e51406a7da3c634f2":[57,14,64],
"group__API__Workers.html#gad58c5fb79e34ec4bf2689213ee4528c3":[57,14,36],
"group__API__Workers.html#gad7c443d1341e4976d63fb5d77e74bf09":[57,14,6],
"group__API__Workers.html#gae1ab43056f2c28ed3826e80c5a86a0fc":[57,14,26],
"group__API__Workers.html#gae1ea590928704bb8578db76422c4022c":[57,14,72],
"group__API__Workers.html#gae35a841f996b8758f3d0ce2ac2d066a5":[57,14,30],
"group__API__Workers.html#gae5eabb8523f44bc9ac81031e05f99f66":[57,14,44],
"group__API__Workers.html#gae6166f338640d033b740f5c8008b851b":[57,14,28],
"group__API__Workers.html#gaec386585a6952f9c7fb47621844fbb39":[57,14,20],
"group__API__Workers.html#gaf48e8da13c523a7a9f2530349ddda29e":[57,14,56],
"group__API__Workers.html#gafc5f2fe263ec932eaf48ab0d313bc322":[57,14,42],
"group__API__Workers.html#gafcf67f47d1addfbe6ca143f04065b00c":[57,14,48],
"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37da26ced4e9dfc43343f0b442bb465218a9":[57,14,9,1],
"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37da5e57c05c04fb13b5383006cfb7719bf5":[57,14,9,4],
"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37da6afc9f886af7206833d473e20d2343e7":[57,14,9,6],
"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37da7fa269b896814504abcf227388233d1f":[57,14,9,0],
"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37dac8fa4358a1bbed68129ebc834ee32bc1":[57,14,9,3],
"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37dad2e8eb63bb5c17adcf205af07deff98c":[57,14,9,2],
"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37dadbf5857b92809e4c81cc7a8b4f7d34c3":[57,14,9,8],
"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37dadc9efedf9b6e4e6ce71d8522f6c1206f":[57,14,9,7],
"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37daf5a63ea6a5480c1a6bcf65db1a4c8761":[57,14,9,5],
"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1a0f41ef0eff3429abe8480b285c8e37d9":[57,14,8,8],
"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1a25ef72894680c188a842f2cefebeb673":[57,14,8,7],
"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1a30be863a2bfc1c5b98c9f2ccdf62394a":[57,14,8,6],
"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1a3bb8e78a9fffd443b2e87d648a1c7531":[57,14,8,3],
"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1a4f0b10cf4c5fb6333b9e3906b81cc5a6":[57,14,8,1],
"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1a59908ef1a8ddbae47f0ff0ed704678af":[57,14,8,4],
"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1aa081477174eb3510759873f06bf5f585":[57,14,8,5],
"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1ad203062edfbde734600e982a54fe5ad2":[57,14,8,9],
"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1adba8e3eb8cbe7ba83bbd4c1707fc5ffd":[57,14,8,0],
"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1aeb7a39d95a8ff63c3d7e1fc479fe923f":[57,14,8,2],
"group__API__Workers.html#gga80b06886ee8a4c0e99b09ab638113af3a2542d005328b674a7479c0c49068f914":[57,14,10,0],
"group__API__Workers.html#gga80b06886ee8a4c0e99b09ab638113af3a574a8ee7f0fc8414cd16767c88481d26":[57,14,10,1],
"group__API__Workers.html#structstarpu__sched__ctx__iterator":[57,14,0],
"group__API__Workers.html#structstarpu__worker__collection":[57,14,1],
"index.html":[0],
"index.html":[],
"index.html#ApplicationTaskification":[0,2],
"index.html#CodeletAndTasks":[0,1,0],
"index.html#Motivation":[0,0],
"index.html#ResearchPapers":[0,3],
"index.html#StarPUDataManagementLibrary":[0,1,1],
"index.html#StarPUInANutshell":[0,1],
"interfacefstarpu__mod_1_1fstarpu__arbiter__create.html":[58,0,0,0],
"interfacefstarpu__mod_1_1fstarpu__arbiter__create.html":[59,0,0,0],
"interfacefstarpu__mod_1_1fstarpu__arbiter__destroy.html":[58,0,0,1],
"interfacefstarpu__mod_1_1fstarpu__arbiter__destroy.html":[59,0,0,1],
"interfacefstarpu__mod_1_1fstarpu__asynchronous__copy__disabled.html":[58,0,0,2],
"interfacefstarpu__mod_1_1fstarpu__asynchronous__copy__disabled.html":[59,0,0,2]
};
